AsyncPayloadBuffer

Struct AsyncPayloadBuffer 

pub struct AsyncPayloadBuffer<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> { /* private fields */ }
An asynchronous version of PayloadBuffer that yields when committing if the queue is full. Dropping this buffer automatically rolls back the payload allocation if not committed.

Implementations

Source

impl<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> AsyncPayloadBuffer<'a, T>

pub fn data(&mut self) -> &mut MutPtrByteSlice<'a>

Returns a mutable slice to the reserved payload bytes.

pub fn offset(&self) -> u32

Returns the absolute VMO offset where this payload reservation begins.

pub async fn commit(self, msg: T) -> Result<(), Status>

Pushes the given message to the FIFO and commits this payload allocation, linking the payload to the queue slot. Yielding if the queue is full.