PayloadBuffer

Struct PayloadBuffer 

pub struct PayloadBuffer<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> { /* private fields */ }
An RAII buffer for committing a payload to the FIFO. Dropping this buffer automatically rolls back the payload allocation.

Implementations

Source

impl<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> PayloadBuffer<'a, T>

pub fn data(&mut self) -> &mut MutPtrByteSlice<'a>

Returns a mutable slice to the payload data.

pub fn offset(&self) -> u32

Returns the physical byte offset of the payload in the VMO.

pub fn commit(self, msg: T) -> Result<(), Status>

Pushes the given message to the FIFO and commits this payload allocation, linking the payload to the queue slot.