pub struct Receiver<T> { /* private fields */ }Expand description
A receiver endpoint for a VMO-backed FIFO queue.
Implementations
Sourceimpl<T: FromBytes + IntoBytes + KnownLayout + Copy> Receiver<T>
impl<T: FromBytes + IntoBytes + KnownLayout + Copy> Receiver<T>
pub fn new(vmo: Vmo, capacity: u32) -> Result<Self, Status>
pub fn is_empty(&self) -> bool
pub fn capacity(&self) -> u32
pub fn index(&self) -> u64
pub fn vmo(&self) -> &Vmo
Sourcepub fn pop_reserve(&mut self) -> Result<T, Status>
pub fn pop_reserve(&mut self) -> Result<T, Status>
Fetches the next message without incrementing the read index.
Sourcepub fn pop_commit(&mut self) -> Result<(), Status>
pub fn pop_commit(&mut self) -> Result<(), Status>
Commit the read, freeing the slot.
Sourcepub fn payload_slice(&self, vmo_offset: u32, len: u32) -> PtrByteSlice<'_>
pub fn payload_slice(&self, vmo_offset: u32, len: u32) -> PtrByteSlice<'_>
Returns a raw slice pointer to the specified payload region.
Panics
Panics if the vmo_offset + len exceeds the bounds of the VMO.