pub struct PayloadBuffer<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> { /* private fields */ }Expand description
An RAII buffer for committing a payload to the FIFO. Dropping this buffer automatically rolls back the payload allocation.
Implementations
Sourceimpl<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> PayloadBuffer<'a, T>
impl<'a, T: FromBytes + IntoBytes + KnownLayout + Copy> PayloadBuffer<'a, T>
Sourcepub fn data(&mut self) -> &mut MutPtrByteSlice<'a>
pub fn data(&mut self) -> &mut MutPtrByteSlice<'a>
Returns a mutable slice to the payload data.