pub struct SyncSender<T>(/* private fields */);Expand description
The synchronous sender endpoint for a VMO-backed FIFO queue.
Implementations
Sourceimpl<T: FromBytes + IntoBytes + KnownLayout + Copy> SyncSender<T>
impl<T: FromBytes + IntoBytes + KnownLayout + Copy> SyncSender<T>
pub fn new( vmo: Vmo, alignment: usize, queue_capacity: u32, ) -> Result<Self, Status>
pub fn capacity(&self) -> u32
pub fn is_full(&self) -> bool
pub fn index(&self) -> u64
pub fn vmo(&self) -> &Vmo
pub fn shutdown(&self) -> Result<(), Status>
pub fn push(&mut self, msg: T) -> Result<u64, Status>
Sourcepub fn reserve_payload(
&mut self,
size: usize,
) -> Result<PayloadBuffer<'_, T>, Status>
pub fn reserve_payload( &mut self, size: usize, ) -> Result<PayloadBuffer<'_, T>, Status>
Reserves capacity in the payload region for a payload of size bytes.
Returns a PayloadBuffer referencing the payload region so that data can be copied or
written directly into it. The returned PayloadBuffer locks the Sender until the buffer
is either committed or dropped, preventing multiple concurrent allocations.